/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.remoting.samples.complex.client;

import org.jboss.remoting.samples.complex.Address;
import org.jboss.remoting.samples.complex.Customer;
import org.jboss.remoting.samples.complex.CustomerProcessor;

/**
 * Simple test client to make an invocation on remoting server.
 *
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 */
public class ComplexClient
{
   public void makeInvocation() throws Throwable
   {
      Customer customer = createCustomer();

      CustomerProcessor processor = CustomerProcessorClient.getCustomerProcessor();

      System.out.println("Customer to be processed: " + customer);

      Customer changedCustomer = processor.processCustomer(customer);

      System.out.println("Customer is now " + changedCustomer);
   }

   private Customer createCustomer()
   {
      Customer cust = new Customer();
      cust.setFirstName("Bob");
      cust.setLastName("Smith");
      Address addr = new Address();
      addr.setStreet("101 Oak Stree");
      addr.setCity("Atlanata");
      addr.setZip(30249);
      cust.setAddr(addr);

      return cust;
   }

   public static void main(String[] args)
   {
      ComplexClient client = new ComplexClient();
      try
      {
         client.makeInvocation();
      }
      catch(Throwable e)
      {
         e.printStackTrace();
      }
   }


}