/*
 * JBoss, Home of Professional Open Source
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.remoting.samples.complex.server;

import java.lang.reflect.Method;
import javax.management.MBeanServer;
import org.jboss.remoting.InvocationRequest;
import org.jboss.remoting.ServerInvocationHandler;
import org.jboss.remoting.ServerInvoker;
import org.jboss.remoting.callback.InvokerCallbackHandler;
import org.jboss.remoting.invocation.NameBasedInvocation;

/**
 * @author <a href="mailto:tom.elrod@jboss.com">Tom Elrod</a>
 */
public class GenericProcessorHandler implements ServerInvocationHandler
{
   private Object processor = null;

   public GenericProcessorHandler(Object processor)
   {
      this.processor = processor;
   }

   /**
    * called to handle a specific invocation.  Please take care to make sure
    * implementations are thread safe and can, and often will, receive concurrent
    * calls on this method.
    *
    * @param invocation
    * @return
    * @throws Throwable
    */
   public Object invoke(InvocationRequest invocation) throws Throwable
   {
      Object request = invocation.getParameter();

      // Am expecting a NameBasedInvocation as the parameter
      NameBasedInvocation nbInvocation = (NameBasedInvocation) request;

      String methodName = nbInvocation.getMethodName();
      Object[] params = nbInvocation.getParameters();
      String[] sig = nbInvocation.getSignature();
      Class[] classSig = new Class[sig.length];
      for(int x = 0; x < sig.length; x++)
      {
         classSig[x] = Class.forName(sig[x]);
      }

      // use reflection to make the call
      Method method = processor.getClass().getMethod(methodName, classSig);
      Object responseObject = method.invoke(processor, params);

      return responseObject;
   }


   /**
    * set the mbean server that the handler can reference
    *
    * @param server
    */
   public void setMBeanServer(MBeanServer server)
   {
      //NOOP
   }

   /**
    * set the invoker that owns this handler
    *
    * @param invoker
    */
   public void setInvoker(ServerInvoker invoker)
   {
      //NOOP
   }

   /**
    * Adds a callback handler that will listen for callbacks from
    * the server invoker handler.
    *
    * @param callbackHandler
    */
   public void addListener(InvokerCallbackHandler callbackHandler)
   {
      //NOOP
   }

   /**
    * Removes the callback handler that was listening for callbacks
    * from the server invoker handler.
    *
    * @param callbackHandler
    */
   public void removeListener(InvokerCallbackHandler callbackHandler)
   {
      //NOOP
   }

}