/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.remoting.samples.complex.server;

import org.jboss.remoting.InvokerLocator;
import org.jboss.remoting.ServerInvocationHandler;
import org.jboss.remoting.transport.Connector;

/**
 * Simple remoting server.  Uses inner class SampleInvocationHandler
 * as the invocation target handler class.
 *
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 */
public abstract class GenericServer
{
   // Default locator values
   private static String transport = "socket";
   private static String host = "localhost";
   private static int port = 5400;

   public abstract Object getProcessor();

   public abstract String getSubSystem();

   public void setupServer() throws Exception
   {
      // create the InvokerLocator based on url string format
      // to indicate the transport, host, and port to use for the
      // server invoker.
      String locatorURI = transport + "://" + host + ":" + port;
      InvokerLocator locator = new InvokerLocator(locatorURI);
      System.out.println("Starting remoting server with locator uri of: " + locatorURI);
      Connector connector = new Connector();
      connector.setInvokerLocator(locator.getLocatorURI());
      // creates all the connector's needed resources, such as the server invoker
      connector.create();

      // create the handler to receive the invocation request from the client for processing
      ServerInvocationHandler invocationHandler = new GenericProcessorHandler(getProcessor());
      // first parameter is sub-system name.  can be any String value.
      connector.addInvocationHandler(getSubSystem(), invocationHandler);

      // start with a new non daemon thread so
      // server will wait for request and not exit
      connector.start();

   }
}